@@ -15,7 +15,7 @@ function xhamsterSearch(query, order) {
     }
 
     var videoFeed = ("http://xhamster.com/search.php?q=" + query.replace(" ", "+") + "&s=" + searchOrder + "&page=1");
-    loadXHamsterVideos(videoFeed, "Search ('" + query + "')");
+    loadXHamsterVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
 
 function loadXHamsterVideos(feed, title) {
@@ -36,7 +36,7 @@ function loadXHamsterVideoInfo(video) {
     loader.item.authorClicked.connect(loadXHamsterUserVideos);
     loader.item.search.connect(xhamsterSearch);
     loader.item.setVideo(video);
-    notificationArea.addTitle("Video Info");
+    notificationArea.addTitle(qsTr("Video Info"));
     windowView.incrementCurrentIndex();
 }
 
@@ -59,7 +59,7 @@ function youjizzSearch(query, order) {
     }
 
     var videoFeed = ("http://youjizz.com/search/" + searchOrder + "_" + query.replace(" ", "-") + "-1.html");
-    loadYouJizzVideos(videoFeed, "Search ('" + query + "')");
+    loadYouJizzVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
 
 function loadYouJizzVideos(feed, title) {
@@ -79,6 +79,6 @@ function loadYouJizzVideoInfo(video) {
     loader.item.goToVideo.connect(loadYouJizzVideoInfo);
     loader.item.search.connect(youjizzSearch);
     loader.item.setVideo(video);
-    notificationArea.addTitle("Video Info");
+    notificationArea.addTitle(qsTr("Video Info"));
     windowView.incrementCurrentIndex();
 }
